@@ -1,4 +1,4 @@
-import trainingpy as tp
+import teamtrain_sdk.trainingpy.trainingpy as tp
 import coloredlogs, logging
 import errno
 import os
